pub struct BuildInstructionsOutput {
pub help_url: Option<String>,
pub http_headers: HashMap<String, String, FxBuildHasher>,
pub instructions: Vec<BuildInstruction>,
pub requirements: Vec<BuildRequirement>,
pub source: Option<SourceLocation>,
pub system_dependencies: Vec<SystemDependency>,
}Expand description
Output returned by the build_instructions function.
Fields
help_url: Option<String>Link to the documentation/help.
http_headers: HashMap<String, String, FxBuildHasher>A map of HTTP headers to include in all requests during the download phase.
instructions: Vec<BuildInstruction>List of instructions to execute to build the tool, after system dependencies have been installed.
requirements: Vec<BuildRequirement>List of requirements that must be met before dependencies are installed and instructions are executed.
source: Option<SourceLocation>Location in which to acquire the source files.
system_dependencies: Vec<SystemDependency>List of system dependencies that are required for building from source. If a dependency does not exist, it will be installed.