FormatsVersion

Trait FormatsVersion 

pub trait FormatsVersion {
    // Required method
    fn to_formatted_string(&self, options: &FormatOptions) -> String;
}
Trait for formatting a version into a string with custom options.

Required Methods

fn to_formatted_string(&self, options: &FormatOptions) -> String

Returns a formatted string representation of the version according to the provided options.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors